src package
===========

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   src.Core

Submodules
----------

src.ascii\_art module
---------------------

.. automodule:: src.ascii_art
   :members:
   :undoc-members:
   :show-inheritance:

src.handwriting module
----------------------

.. automodule:: src.handwriting
   :members:
   :undoc-members:
   :show-inheritance:

src.mail module
---------------

.. automodule:: src.mail
   :members:
   :undoc-members:
   :show-inheritance:

src.misc module
---------------

.. automodule:: src.misc
   :members:
   :undoc-members:
   :show-inheritance:

src.remotekit module
--------------------

.. automodule:: src.remotekit
   :members:
   :undoc-members:
   :show-inheritance:

src.sc module
-------------

.. automodule:: src.sc
   :members:
   :undoc-members:
   :show-inheritance:

src.whats module
----------------

.. automodule:: src.whats
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: src
   :members:
   :undoc-members:
   :show-inheritance:
